@@ -4,7 +4,7 @@ import { IDocumentManager } from '@jupyterlab/docmanager';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { SETTINGS_ID, getTransformerEnabled } from './settings';
 import { CellMetadataEditor, IProps as EditorProps } from './widgets/CellMetadataEditor';
-import { Cell, isCodeCellModel } from '@jupyterlab/cells';
+import { Cell, isCodeCellModel, isRawCellModel } from '@jupyterlab/cells';
 import * as React from 'react';
 import * as ReactDOM from 'react-dom';
 import TagsUtils from './lib/TagsUtils';
@@ -40,9 +40,8 @@ const handleNotebookChanged = async (notebookTracker: INotebookTracker, notebook
         });
 
         notebookPanel.model.cells.changed.connect((cells: IObservableUndoableList<ICellModel>, change: IObservableList.IChangedArgs<ICellModel>) => {
-            if(editors.length != notebookPanel.model.cells.length) {
-                makeCellTransformerWidgets(notebookPanel);
-            }
+            console.log("Cell change now...");
+            makeCellTransformerWidgets(notebookPanel);
         });
 
         const cmd: string = 'import os\n' + 'dir = os.getcwd()';
@@ -63,13 +62,14 @@ const handleNotebookChanged = async (notebookTracker: INotebookTracker, notebook
 const makeCellTransformerWidgets = (notebookPanel: NotebookPanel) => {
     const cells = notebookPanel.model.cells;
     for (let index = 0; index < cells.length; index++) {
-        const isCodeCell = isCodeCellModel(cells.get(index));
         let cellId: string = cells.get(index).id;
         let existedItems = editors.filter(item => item['cellId'] === cellId);
         if(existedItems.length > 0) {
             continue;
         }
-        if (! isCodeCell) {
+        let isCodeCell: boolean = isCodeCellModel(cells.get(index));
+        let isRawCell: boolean = isRawCellModel(cells.get(index));
+        if ((! isCodeCell) && (! isRawCell)) {
             continue;
         }
         let transformerTag: string = TagsUtils.getCellTransformerTag(notebookPanel, index)? TagsUtils.getCellTransformerTag(notebookPanel, index) : null;
