@@ -4,7 +4,7 @@ import CheckIcon from '@material-ui/icons/Check';
 import { IconButton } from '@material-ui/core';
 import { Select } from './../components/Select';
 import TagsUtils from './../lib/TagsUtils';
-import { Notebook, NotebookPanel } from '@jupyterlab/notebook';
+import { Notebook, NotebookPanel/*, NotebookActions*/ } from '@jupyterlab/notebook';
 import { Chip, Tooltip } from '@material-ui/core';
 import { CellMetadataEditorDialog } from './CellMetadataEditorDialog';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
@@ -18,6 +18,7 @@ const CELL_TYPE_NA_LABEL = '-';
 export const CELL_TYPE_PREPROCESSOR = 'preprocessor';
 export const CELL_TYPE_POSTPROCESSOR = 'postprocessor';
 export const CELL_TYPE_REQUIREMENTS = 'requirements';
+export const CELL_TYPE_CVAT_INFO = 'cvat-info';
 const CELL_TYPES: any[] = [
     {
         value: CELL_TYPE_NA,
@@ -48,6 +49,12 @@ const CELL_TYPES: any[] = [
         label: 'Extra functions',
         helpText: 'The code in this cell will be parsed as referenced function for the preprocessor or postprocessor.',
         chipColor: 'a32626'
+    },
+    {
+        value: CELL_TYPE_CVAT_INFO,
+        label: 'CVAT Info',
+        helpText: 'The code in this cell will be parsed as cvat_info callback function.',
+        chipColor: 'a32626'
     }
 ];
 
@@ -88,6 +95,16 @@ const POSTPROCESSOR_DEFAULT_CODE_SNIPPET = `from typing import Dict
 def postprocess(input: Dict) -> Dict:
     return input`
 
+const CVAT_INFO_DEF_REGEX = /\s*def\s+cvat_info\s*\(\s*\S*\s*(:\s*\S+\s*)*(=\s*('|")*\S+('|")*\s*)*\)\s*(->\s*\S+\s*)*:\s*/i
+const CVAT_INFO_DEFAULT_CODE_SNIPPET = `from typing import Dict
+def cvat_info(inputs: Dict = None) -> Dict:
+    return {
+        "framework": "",
+        "spec": None,
+        "type": "",
+        "description": ""
+    }`
+
 const enum CellCodeErrors {
   VOID,
   FUNC_DEF_ERROR
@@ -148,6 +165,8 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
             return this.transformerStates.isPostprocessorTagged;
         } else if(tag === CELL_TYPE_REQUIREMENTS) {
             return this.transformerStates.isRequirementsTagged;
+        } else if(tag === CELL_TYPE_CVAT_INFO) {
+            return this.transformerStates.isCVATInfoTagged;
         }
         return false;
     }
@@ -159,6 +178,8 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
             this.transformerStates.isPostprocessorTagged = tagged;
         } else if(tag === CELL_TYPE_REQUIREMENTS) {
             this.transformerStates.isRequirementsTagged = tagged;
+        } else if(tag === CELL_TYPE_CVAT_INFO) {
+            this.transformerStates.isCVATInfoTagged = tagged;
         }
     }
 
@@ -176,10 +197,12 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
 
     checkCellCodeDefinitionConfirmed = (notebook: Notebook, cellIndex: number, tag: string) => {
         console.log("checkCellCodeDefinitionConfirmed");
-        if(tag == CELL_TYPE_PREPROCESSOR || tag == CELL_TYPE_POSTPROCESSOR) {
+        if(tag == CELL_TYPE_PREPROCESSOR || tag == CELL_TYPE_POSTPROCESSOR || tag == CELL_TYPE_CVAT_INFO) {
             let regex = PREPROCESSOR_DEF_REGEX;
             if(tag == CELL_TYPE_POSTPROCESSOR) {
                 regex = POSTPROCESSOR_DEF_REGEX;
+            } else if(tag == CELL_TYPE_CVAT_INFO) {
+                regex = CVAT_INFO_DEF_REGEX;
             }
             if(CellUtils.isCellVoid(notebook, cellIndex)) {
                 return {
@@ -199,7 +222,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
         }
     }
 
-    updateCurrentCellTag = (value: string) => {
+    updateCurrentCellTag = async (value: string) => {
         if(value !== this.state.transformerTag) {
             this.updateLocalTransformerStates(this.state.transformerTag, false);
             this.updateLocalTransformerStates(value, true);
@@ -210,13 +233,15 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                 this.setState({ transformerTag: CELL_TYPE_NA });
             }
 
-            if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR) {
+            if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO) {
                 let notebook: Notebook = this.props.notebookPanel.content;
                 let confirmedResult = this.checkCellCodeDefinitionConfirmed(notebook, notebook.activeCellIndex, value);
                 if(! confirmedResult.confirmed) {
                     let codeSnippet = PREPROCESSOR_DEFAULT_CODE_SNIPPET;
                     if(value == CELL_TYPE_POSTPROCESSOR) {
                         codeSnippet = POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_INFO) {
+                        codeSnippet = CVAT_INFO_DEFAULT_CODE_SNIPPET;
                     }
                     if(confirmedResult.error == CellCodeErrors.VOID) {
                         CellUtils.injectCodeAtIndex(notebook, notebook.activeCellIndex, codeSnippet);
@@ -231,6 +256,13 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                         this.toggleTagsEditorDialog();
                     }
                 }
+                //NotebookActions.changeCellType(this.props.notebookPanel.content, 'code');
+            } else if(value == CELL_TYPE_REQUIREMENTS) {
+                /*
+                await this.props.notebookPanel.context.save();
+                NotebookActions.changeCellType(this.props.notebookPanel.content, 'raw');
+                this.props.notebookPanel.activate();
+                */
             }
         }
     };
@@ -238,7 +270,8 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
     saveCellTagInNotebookFile = () => {
         console.log("saveCellTagInNotebookFile");
         let value = this.state.transformerTag;
-        if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR) {
+
+        if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO) {
             let notebook: Notebook = this.props.notebookPanel.content;
             let confirmedResult = this.checkCellCodeDefinitionConfirmed(notebook, notebook.activeCellIndex, value);
             if(! confirmedResult.confirmed) {
@@ -257,6 +290,8 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                     let codeSnippet = PREPROCESSOR_DEFAULT_CODE_SNIPPET;
                     if(value == CELL_TYPE_POSTPROCESSOR) {
                         codeSnippet = POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_INFO) {
+                        codeSnippet = CVAT_INFO_DEFAULT_CODE_SNIPPET;
                     }
                     let dialogTitle = "Function %s is not well defined!".replace(/%s/i, value);
                     let dialogContent = "Please define function %s as follows:".replace(/%s/i, value);
@@ -390,7 +425,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
     }
 
     render() {
-        const cellType = RESERVED_CELL_NAMES.includes(this.state.transformerTag)? this.state.transformerTag : 'na';
+        const cellTag = RESERVED_CELL_NAMES.includes(this.state.transformerTag)? this.state.transformerTag : 'na';
         const cellColor = 'transparent';
 
         // add class names for styling
@@ -436,8 +471,8 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                         <Select
                             updateValue={this.updateCurrentCellTag}
                             values={this.state.typeSelectOptions}
-                            value={cellType}
-                            label={'Cell type'}
+                            value={cellTag}
+                            label={'Cell tag'}
                             index={0}
                             variant="outlined"
                             style={{ width: 'auto', minWidth: '14em' }}
